@@ -5,6 +5,7 @@
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
+// clazy:excludeall=lambda-in-connect
 
 #include "mailclient_p.h"
 using namespace Qt::Literals::StringLiterals;
@@ -31,6 +32,8 @@ using namespace Qt::Literals::StringLiterals;
 #include <gpgme++/context.h>
 #include <gpgme++/importresult.h>
 
+#include <gpgme.h>
+
 #include <MessageComposer/ComposerJob>
 #include <MessageComposer/ContactPreference>
 #include <MessageComposer/GlobalPart>
@@ -112,8 +115,8 @@ static QStringList extractEmailAndNormalize(const QString &email)
     const QStringList splittedEmail = KEmailAddress::splitAddressList(email);
     QStringList normalizedEmail;
     normalizedEmail.reserve(splittedEmail.count());
-    for (const QString &email : splittedEmail) {
-        const QString str = KEmailAddress::extractEmailAddress(KEmailAddress::normalizeAddressesAndEncodeIdn(email));
+    for (const QString &emailItem : splittedEmail) {
+        const QString str = KEmailAddress::extractEmailAddress(KEmailAddress::normalizeAddressesAndEncodeIdn(emailItem));
         normalizedEmail << str;
     }
     return normalizedEmail;
@@ -187,7 +190,7 @@ MailClient::buildComposers(const KCalendarCore::IncidenceBase::Ptr &incidence, c
     bool encryptSomething = msg.encrypt;
     const bool doEncryptCompletely = msg.encrypt;
 
-    std::unique_ptr<ITIPHandlerDialogDelegate> dialogDelegate(
+    std::unique_ptr<ITIPHandlerDialogDelegate> const dialogDelegate(
         mFactory->createITIPHanderDialogDelegate(qSharedPointerCast<KCalendarCore::Incidence>(incidence), KCalendarCore::iTIPMethod::iTIPNoMethod));
 
     auto expiryChecker = std::make_shared<Kleo::ExpiryChecker>(Kleo::ExpiryCheckerSettings{encryptOwnKeyNearExpiryWarningThresholdInDays(),
@@ -245,21 +248,20 @@ MailClient::buildComposers(const KCalendarCore::IncidenceBase::Ptr &incidence, c
         const auto preferredCrypto = Kleo::stringToCryptoMessageFormat(identity.preferredCryptoMessageFormat());
         if (preferredCrypto & Kleo::OpenPGPMIMEFormat) {
             composerJob->setAutocryptEnabled(identity.autocryptEnabled());
-            if (keyResolver.encryptToSelfKeysFor(Kleo::OpenPGPMIMEFormat).size() > 0) {
+            if (!keyResolver.encryptToSelfKeysFor(Kleo::OpenPGPMIMEFormat).empty()) {
                 composerJob->setSenderEncryptionKey(keyResolver.encryptToSelfKeysFor(Kleo::OpenPGPMIMEFormat)[0]);
             }
         }
         return composerJobs;
     }
 
-    canceled = false;
     const auto kpgpResult = keyResolver.resolveAllKeys(signSomething, encryptSomething);
-    if (kpgpResult == MessageComposer::ResolverResult::Canceled || canceled) {
+    if (kpgpResult == MessageComposer::ResolverResult::Canceled) {
         qCDebug(AKONADICALENDAR_LOG) << "resolveAllKeys: one key resolution canceled by user";
         return {};
     } else if (kpgpResult != MessageComposer::ResolverResult::Ok) {
         // TODO handle failure
-        qCDebug(AKONADICALENDAR_LOG) << "resolveAllKeys: failed to resolve keys! oh noes";
+        qCDebug(AKONADICALENDAR_LOG) << "resolveAllKeys: failed to resolve keys! oh no";
         return {};
     }
 
@@ -288,7 +290,7 @@ MailClient::buildComposers(const KCalendarCore::IncidenceBase::Ptr &incidence, c
                     composerJob->setAutocryptEnabled(true);
                     composerJob->setSenderEncryptionKey(keyResolver.encryptToSelfKeysFor(concreteFormat)[0]);
                     QTemporaryDir dir;
-                    bool specialGnupgHome = addKeysToContext(dir.path(), data, keyResolver.useAutocrypt());
+                    bool const specialGnupgHome = addKeysToContext(dir.path(), data, keyResolver.useAutocrypt());
                     if (specialGnupgHome) {
                         dir.setAutoRemove(false);
                         composerJob->setGnupgHome(dir.path());
@@ -335,7 +337,9 @@ void MailClient::queueMessage(const MailTransport::Transport *transport,
         }
     }
 
-    qjob->transportAttribute().setTransportId(transport->id());
+    if (transport) {
+        qjob->transportAttribute().setTransportId(transport->id());
+    }
 
     if (transport && transport->specifySenderOverwriteAddress()) {
         qjob->addressAttribute().setFrom(
@@ -372,7 +376,7 @@ void MailClient::mailAttendees(const KCalendarCore::IncidenceBase::Ptr &incidenc
                                MailPrivacyFlags mailPrivacy)
 {
     Q_ASSERT(incidence);
-    KCalendarCore::Attendee::List attendees = incidence->attendees();
+    KCalendarCore::Attendee::List const attendees = incidence->attendees();
     if (attendees.isEmpty()) {
         qCWarning(AKONADICALENDAR_LOG) << "There are no attendees to e-mail";
         Q_EMIT finished(ResultNoAttendees, i18n("There are no attendees to e-mail"));
@@ -389,7 +393,7 @@ void MailClient::mailAttendees(const KCalendarCore::IncidenceBase::Ptr &incidenc
 
     const int numberOfAttendees = attendees.count();
     for (int i = 0; i < numberOfAttendees; ++i) {
-        const KCalendarCore::Attendee a = attendees.at(i);
+        const KCalendarCore::Attendee &a = attendees.at(i);
 
         const QString email = a.email();
         if (email.isEmpty()) {
@@ -417,9 +421,8 @@ void MailClient::mailAttendees(const KCalendarCore::IncidenceBase::Ptr &incidenc
         return;
     }
 
-    QString subject;
     if (incidence->type() != KCalendarCore::Incidence::TypeFreeBusy) {
-        KCalendarCore::Incidence::Ptr inc = incidence.staticCast<KCalendarCore::Incidence>();
+        KCalendarCore::Incidence::Ptr const inc = incidence.staticCast<KCalendarCore::Incidence>();
         msg.subject = inc->summary();
     } else {
         msg.subject = i18n("Free Busy Object");
@@ -451,7 +454,7 @@ void MailClient::mailOrganizer(const KCalendarCore::IncidenceBase::Ptr &incidenc
     msg.method = KCalendarCore::ScheduleMessage::methodName(method);
 
     if (incidence->type() != KCalendarCore::Incidence::TypeFreeBusy) {
-        KCalendarCore::Incidence::Ptr inc = incidence.staticCast<KCalendarCore::Incidence>();
+        KCalendarCore::Incidence::Ptr const inc = incidence.staticCast<KCalendarCore::Incidence>();
         if (msg.subject.isEmpty()) {
             msg.subject = inc->summary();
         }
@@ -484,7 +487,7 @@ void MailClient::mailTo(const KCalendarCore::IncidenceBase::Ptr &incidence,
     msg.method = KCalendarCore::ScheduleMessage::methodName(method);
 
     if (incidence->type() != KCalendarCore::Incidence::TypeFreeBusy) {
-        KCalendarCore::Incidence::Ptr inc = incidence.staticCast<KCalendarCore::Incidence>();
+        KCalendarCore::Incidence::Ptr const inc = incidence.staticCast<KCalendarCore::Incidence>();
         msg.subject = inc->summary();
     } else {
         msg.subject = i18n("Free Busy Message");
@@ -501,7 +504,7 @@ void MailClient::populateComposer(MessageComposer::ComposerJob *composerJob, con
 {
     // gather config values
     KConfig config(u"kmail2rc"_s);
-    KConfigGroup configGroup(&config, u"Invitations"_s);
+    KConfigGroup const configGroup(&config, u"Invitations"_s);
     const bool outlookConformInvitation = configGroup.readEntry("LegacyBodyInvites",
 #ifdef KDEPIM_ENTERPRISE_BUILD
                                                                 true
@@ -569,6 +572,7 @@ bool MailClient::addKeysToContext(const QString &gnupgHome,
             if (it == autocryptMap.end()) {
                 qCDebug(AKONADICALENDAR_LOG) << "Adding " << k.primaryFingerprint() << "via Export/Import";
                 auto exportJob = proto->publicKeyExportJob(false);
+                // clazy reports this as a lambda-in-connect issue. false positive
                 connect(exportJob,
                         &QGpgME::ExportJob::result,
                         exportJob,
@@ -579,7 +583,11 @@ bool MailClient::addKeysToContext(const QString &gnupgHome,
                             Q_UNUSED(auditLogAsHtml);
                             Q_UNUSED(auditLogError);
                             if (result) {
+#if GPGME_VERSION_NUMBER >= 0x011800 // 1.24.0
+                                qCWarning(AKONADICALENDAR_LOG) << "Failed to export " << k.primaryFingerprint() << result.asStdString();
+#else
                                 qCWarning(AKONADICALENDAR_LOG) << "Failed to export " << k.primaryFingerprint() << result.asString();
+#endif
                                 --runningJobs;
                                 if (runningJobs < 1) {
                                     loop.quit();
@@ -654,8 +662,9 @@ void MailClient::send(const KCalendarCore::IncidenceBase::Ptr &incidence,
         populateComposer(composerJobPtr.get(), msg);
         auto *composerJob = composerJobPtr.release();
         QObject::connect(composerJob, &MessageComposer::ComposerJob::result, this, [this, transport, composerJob, incidence, identity, msg]() {
-            for (const auto &message : composerJob->resultMessages()) {
-                queueMessage(transport, composerJob, incidence, identity, msg, message);
+            const auto resultMessageList = composerJob->resultMessages();
+            for (const auto &resultMessage : resultMessageList) {
+                queueMessage(transport, composerJob, incidence, identity, msg, resultMessage);
             }
             composerJob->deleteLater();
         });
